==> 0.0.5.tar.gz: lib/ads/banner_ads.dart <==
import 'dart:math';
import 'package:admob_flutter/admob_flutter.dart';
import 'package:bcs_ads_manager/ads/custom/custom_banner_ads.dart';
import 'package:bcs_ads_manager/ads/enum/ads_platform_enum.dart';
import 'package:flutter/material.dart';
import 'package:unity_ads_plugin/unity_ads_plugin.dart';
import 'model/admob_settings.dart';

class BannerAds extends StatefulWidget {
  final AdmobSettings? admobSettings;
  final bool isTestAds;

  const BannerAds({Key? key, this.admobSettings, required this.isTestAds}) : super(key: key);

  @override
  _BannerAdsState createState() => _BannerAdsState();
}

class _BannerAdsState extends State<BannerAds> {

  Widget bannerView = Container();

  @override
  void initState() {
    // TODO: implement initState
    super.initState();

    WidgetsBinding.instance?.addPostFrameCallback((_) {
      showSmartBannerAds();
    });
  }

  /**
   * It will use to fetch random available ads.
   */
  Widget showSmartBannerAds()
  {
    int googleAdsRange = widget.admobSettings!.googleAds!.visibilityPercentage!;
    int unityAdsPackageRange =
        googleAdsRange + widget.admobSettings!.unityAds!.visibilityPercentage!;
    int customAdsRange = unityAdsPackageRange +
        widget.admobSettings!.customAds!.visibilityPercentage!; // total range

    /// Default selection.
    AdsPlatformEnum currentAdsPlatformEnum = AdsPlatformEnum.NONE;

    /// find random range for ads.
    Random rnd = Random();
    int randomNumber = rnd.nextInt(customAdsRange);

    if(widget.admobSettings!.isBannerAds == true) {
      if (randomNumber <= googleAdsRange) {
        if (widget.admobSettings!.googleAds!.isBannerAds == true && widget.admobSettings!.googleAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.GOOGLE_ADMOB;
        } else if (widget.admobSettings!.unityAds!.isBannerAds == true && widget.admobSettings!.unityAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.UNITY_ADS;
        } else if (widget.admobSettings!.customAds!.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.CUSTOME_ADS;
        }
      }
      else if (randomNumber > googleAdsRange &&
          randomNumber <= unityAdsPackageRange) {
        if (widget.admobSettings!.unityAds!.isBannerAds == true && widget.admobSettings!.unityAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.UNITY_ADS;
        } else if (widget.admobSettings!.googleAds!.isBannerAds == true && widget.admobSettings!.googleAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.GOOGLE_ADMOB;
        } else if (widget.admobSettings!.customAds!.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.CUSTOME_ADS;
        }
      }
      else if (randomNumber > unityAdsPackageRange &&
          randomNumber <= customAdsRange) {
        if (widget.admobSettings!.customAds!.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.CUSTOME_ADS;
        } else if (widget.admobSettings!.googleAds!.isBannerAds == true && widget.admobSettings!.googleAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.GOOGLE_ADMOB;
        } else if (widget.admobSettings!.unityAds!.isBannerAds == true && widget.admobSettings!.unityAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.UNITY_ADS;
        }
      }
    }

    /// default view.
    setState(() {
      if (currentAdsPlatformEnum != AdsPlatformEnum.NONE)
      {
        bannerView = SizedBox(
          height: 55,
          child: Stack(
            children: [
              if (currentAdsPlatformEnum == AdsPlatformEnum.GOOGLE_ADMOB) ...[
                getGoogleBannerAds(
                    onFailLoad: (){
                      if(widget.admobSettings?.unityAds?.isBannerAds == true && widget.admobSettings!.unityAds!.visibilityPercentage! > 0)
                      {
                        bannerView = SizedBox(
                          height: 55,
                          child: Stack(
                            children: [
                              getUnityBannerAds(
                                  onFailLoad: (){
                                    if(widget.admobSettings?.customAds?.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0)
                                    {
                                      bannerView = SizedBox(
                                        height: 55,
                                        child: Stack(
                                          children: [
                                            getCustomBannerAds(
                                                onFailLoad: (){
                                                  bannerView = Container();
                                                }
                                            )
                                          ],
                                        ),
                                      );
                                    }
                                    else
                                    {
                                      bannerView = Container();
                                    }
                                  }
                              )
                            ],
                          ),
                        );
                      }
                      else{
                        if(widget.admobSettings?.customAds?.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0)
                        {
                          bannerView = SizedBox(
                            height: 55,
                            child: Stack(
                              children: [
                                getCustomBannerAds(
                                    onFailLoad: (){
                                      bannerView = Container();
                                    }
                                )
                              ],
                            ),
                          );
                        }
                        else{
                          bannerView = Container();
                        }
                      }
                    }
                )
              ]
              else if (currentAdsPlatformEnum == AdsPlatformEnum.UNITY_ADS) ...[
                getUnityBannerAds(
                    onFailLoad: (){
                      if(widget.admobSettings?.googleAds?.isBannerAds == true && widget.admobSettings!.googleAds!.visibilityPercentage! > 0)
                      {
                        bannerView = SizedBox(
                          height: 55,
                          child: Stack(
                            children: [
                              getGoogleBannerAds(
                                  onFailLoad: (){
                                    if(widget.admobSettings?.customAds?.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0)
                                    {
                                      bannerView = SizedBox(
                                        height: 55,
                                        child: Stack(
                                          children: [
                                            getCustomBannerAds(
                                                onFailLoad: (){
                                                  bannerView = Container();
                                                }
                                            )
                                          ],
                                        ),
                                      );
                                    }
                                    else
                                    {
                                      bannerView = Container();
                                    }
                                  }
                              )
                            ],
                          ),
                        );
                      }
                      else{
                        if(widget.admobSettings?.customAds?.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0)
                        {
                          bannerView = SizedBox(
                            height: 55,
                            child: Stack(
                              children: [
                                getCustomBannerAds(
                                    onFailLoad: (){
                                      bannerView = Container();
                                    }
                                )
                              ],
                            ),
                          );
                        }
                        else{
                          bannerView = Container();
                        }
                      }
                    }
                )
              ] else if (currentAdsPlatformEnum == AdsPlatformEnum.CUSTOME_ADS) ...[
                getCustomBannerAds(onFailLoad: (){
                  bannerView = Container();
                })
              ]
              else ...[
                  Container()
                ],

            ],
          ),
        );
      }
      else
      {
        bannerView = Container();
      }
    });

    return bannerView;
  }

  /**
   * It will return google banner ads.
   */
  Widget getGoogleBannerAds({Function? onFailLoad})
  {
    String? adUnit = (widget.isTestAds)? 'ca-app-pub-3940256099942544/6300978111':widget.admobSettings!.googleAds!.bannerAdUnitIdAndroid;
    return AdmobBanner(
        adUnitId:adUnit!,
        adSize: AdmobBannerSize.BANNER,
        listener: (AdmobAdEvent event,
            Map<String, dynamic>? args) {
          if (event == AdmobAdEvent.failedToLoad)
          {
            if (onFailLoad != null) {
              onFailLoad();
            }
          }
        }
      );
  }

  /**
   * It will return unity banner ads.
   */
  Widget getUnityBannerAds({Function? onFailLoad})
  {
    return UnityBannerAd(
        placementId: 'Banner_Android',
        onFailed: (placementId, error, message) {
          if (onFailLoad != null) {
              onFailLoad();
            }
        });
  }

  /**
   * It will return custom banner ads.
   */
  Widget getCustomBannerAds({Function? onFailLoad})
  {
    return CustomBannerAds(admobSettings: widget.admobSettings);
  }



  @override
  Widget build(BuildContext context)
  {
    return StatefulBuilder(
        builder: (thisLowerContext, innerSetState) {
          return bannerView;
    });
  }
}

==> 0.0.6.tar.gz: lib/ads/banner_ads.dart <==
import 'dart:math';
import 'package:admob_flutter/admob_flutter.dart';
import 'package:bcs_ads_manager/ads/custom/custom_banner_ads.dart';
import 'package:bcs_ads_manager/ads/enum/ads_platform_enum.dart';
import 'package:flutter/material.dart';
import 'package:unity_ads_plugin/unity_ads_plugin.dart';
import 'model/admob_settings.dart';

class BannerAds extends StatefulWidget {
  final AdmobSettings? admobSettings;
  final bool isTestAds;

  const BannerAds({Key? key, this.admobSettings, required this.isTestAds}) : super(key: key);

  @override
  _BannerAdsState createState() => _BannerAdsState();
}

class _BannerAdsState extends State<BannerAds> {

  Widget bannerView = Container(height: 0,);

  @override
  void initState() {
    // TODO: implement initState
    super.initState();

    WidgetsBinding.instance?.addPostFrameCallback((_) {
      showSmartBannerAds();
    });
  }

  /**
   * It will use to fetch random available ads.
   */
  Widget showSmartBannerAds()
  {
    int googleAdsRange = widget.admobSettings!.googleAds!.visibilityPercentage!;
    int unityAdsPackageRange =
        googleAdsRange + widget.admobSettings!.unityAds!.visibilityPercentage!;
    int customAdsRange = unityAdsPackageRange +
        widget.admobSettings!.customAds!.visibilityPercentage!; // total range

    /// Default selection.
    AdsPlatformEnum currentAdsPlatformEnum = AdsPlatformEnum.NONE;

    /// find random range for ads.
    Random rnd = Random();
    int randomNumber = rnd.nextInt(customAdsRange);

    if(widget.admobSettings!.isBannerAds == true) {
      if (randomNumber <= googleAdsRange) {
        if (widget.admobSettings!.googleAds!.isBannerAds == true && widget.admobSettings!.googleAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.GOOGLE_ADMOB;
        } else if (widget.admobSettings!.unityAds!.isBannerAds == true && widget.admobSettings!.unityAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.UNITY_ADS;
        } else if (widget.admobSettings!.customAds!.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.CUSTOME_ADS;
        }
      }
      else if (randomNumber > googleAdsRange &&
          randomNumber <= unityAdsPackageRange) {
        if (widget.admobSettings!.unityAds!.isBannerAds == true && widget.admobSettings!.unityAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.UNITY_ADS;
        } else if (widget.admobSettings!.googleAds!.isBannerAds == true && widget.admobSettings!.googleAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.GOOGLE_ADMOB;
        } else if (widget.admobSettings!.customAds!.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.CUSTOME_ADS;
        }
      }
      else if (randomNumber > unityAdsPackageRange &&
          randomNumber <= customAdsRange) {
        if (widget.admobSettings!.customAds!.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.CUSTOME_ADS;
        } else if (widget.admobSettings!.googleAds!.isBannerAds == true && widget.admobSettings!.googleAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.GOOGLE_ADMOB;
        } else if (widget.admobSettings!.unityAds!.isBannerAds == true && widget.admobSettings!.unityAds!.visibilityPercentage! > 0) {
          currentAdsPlatformEnum = AdsPlatformEnum.UNITY_ADS;
        }
      }
    }

    /// default view.
    setState(() {
      if (currentAdsPlatformEnum != AdsPlatformEnum.NONE)
      {
        bannerView = SizedBox(
          height: 55,
          child: Stack(
            children: [
              if (currentAdsPlatformEnum == AdsPlatformEnum.GOOGLE_ADMOB) ...[
                getGoogleBannerAds(
                    onFailLoad: (){
                      if(widget.admobSettings?.unityAds?.isBannerAds == true && widget.admobSettings!.unityAds!.visibilityPercentage! > 0)
                      {
                        bannerView = SizedBox(
                          height: 55,
                          child: Stack(
                            children: [
                              getUnityBannerAds(
                                  onFailLoad: (){
                                    if(widget.admobSettings?.customAds?.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0)
                                    {
                                      bannerView = SizedBox(
                                        height: 55,
                                        child: Stack(
                                          children: [
                                            getCustomBannerAds(
                                                onFailLoad: (){
                                                  bannerView = Container(height: 0,);
                                                }
                                            )
                                          ],
                                        ),
                                      );
                                    }
                                    else
                                    {
                                      bannerView = Container(height: 0,);
                                    }
                                  }
                              )
                            ],
                          ),
                        );
                      }
                      else{
                        if(widget.admobSettings?.customAds?.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0)
                        {
                          bannerView = SizedBox(
                            height: 55,
                            child: Stack(
                              children: [
                                getCustomBannerAds(
                                    onFailLoad: (){
                                      bannerView = Container(height: 0,);
                                    }
                                )
                              ],
                            ),
                          );
                        }
                        else{
                          bannerView = Container(height: 0,);
                        }
                      }
                    }
                )
              ]
              else if (currentAdsPlatformEnum == AdsPlatformEnum.UNITY_ADS) ...[
                getUnityBannerAds(
                    onFailLoad: (){
                      if(widget.admobSettings?.googleAds?.isBannerAds == true && widget.admobSettings!.googleAds!.visibilityPercentage! > 0)
                      {
                        bannerView = SizedBox(
                          height: 55,
                          child: Stack(
                            children: [
                              getGoogleBannerAds(
                                  onFailLoad: (){
                                    if(widget.admobSettings?.customAds?.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0)
                                    {
                                      bannerView = SizedBox(
                                        height: 55,
                                        child: Stack(
                                          children: [
                                            getCustomBannerAds(
                                                onFailLoad: (){
                                                  bannerView = Container(height: 0,);
                                                }
                                            )
                                          ],
                                        ),
                                      );
                                    }
                                    else
                                    {
                                      bannerView = Container(height: 0,);
                                    }
                                  }
                              )
                            ],
                          ),
                        );
                      }
                      else{
                        if(widget.admobSettings?.customAds?.isBannerAds == true && widget.admobSettings!.customAds!.visibilityPercentage! > 0)
                        {
                          bannerView = SizedBox(
                            height: 55,
                            child: Stack(
                              children: [
                                getCustomBannerAds(
                                    onFailLoad: (){
                                      bannerView = Container(height: 0,);
                                    }
                                )
                              ],
                            ),
                          );
                        }
                        else{
                          bannerView = Container(height: 0,);
                        }
                      }
                    }
                )
              ] else if (currentAdsPlatformEnum == AdsPlatformEnum.CUSTOME_ADS) ...[
                getCustomBannerAds(onFailLoad: (){
                  bannerView = Container(height: 0,);
                })
              ]
              else ...[
                  Container(height: 0,)
                ],

            ],
          ),
        );
      }
      else
      {
        bannerView = Container(height: 0,);
      }
    });

    return bannerView;
  }

  /**
   * It will return google banner ads.
   */
  Widget getGoogleBannerAds({Function? onFailLoad})
  {
    String? adUnit = (widget.isTestAds)? 'ca-app-pub-3940256099942544/6300978111':widget.admobSettings!.googleAds!.bannerAdUnitIdAndroid;
    return AdmobBanner(
        adUnitId:adUnit!,
        adSize: AdmobBannerSize.BANNER,
        listener: (AdmobAdEvent event,
            Map<String, dynamic>? args) {
          if (event == AdmobAdEvent.failedToLoad)
          {
            if (onFailLoad != null) {
              onFailLoad();
            }
          }
        }
      );
  }

  /**
   * It will return unity banner ads.
   */
  Widget getUnityBannerAds({Function? onFailLoad})
  {
    return UnityBannerAd(
        placementId: 'Banner_Android',
        onFailed: (placementId, error, message) {
          if (onFailLoad != null) {
              onFailLoad();
            }
        });
  }

  /**
   * It will return custom banner ads.
   */
  Widget getCustomBannerAds({Function? onFailLoad})
  {
    return CustomBannerAds(admobSettings: widget.admobSettings);
  }



  @override
  Widget build(BuildContext context)
  {
    return StatefulBuilder(
        builder: (thisLowerContext, innerSetState) {
          return bannerView;
    });
  }
}
